@@ -22,8 +22,8 @@ import (
 	"strings"
 	"testing"
 
-	"github.com/go-kit/log"
 	"github.com/prometheus/client_golang/prometheus/testutil"
+	"github.com/prometheus/common/promslog"
 )
 
 func TestILMStatus(t *testing.T) {
@@ -39,7 +39,7 @@ func TestILMStatus(t *testing.T) {
 			name: "6.6.0",
 			file: "../fixtures/ilm_status/6.6.0.json",
 			want: `
-# HELP elasticsearch_ilm_status Current status of ilm. Status can be STOPPED, RUNNING, STOPPING.
+# HELP elasticsearch_ilm_status Current status of ILM. Status can be STOPPED, RUNNING, STOPPING.
 # TYPE elasticsearch_ilm_status gauge
 elasticsearch_ilm_status{operation_mode="RUNNING"} 1
 elasticsearch_ilm_status{operation_mode="STOPPED"} 0
@@ -66,7 +66,7 @@ elasticsearch_ilm_status{operation_mode="STOPPING"} 0
 				t.Fatal(err)
 			}
 
-			c := NewIlmStatus(log.NewNopLogger(), http.DefaultClient, u)
+			c := NewIlmStatus(promslog.NewNopLogger(), http.DefaultClient, u)
 			if err != nil {
 				t.Fatal(err)
 			}
