@@ -17,13 +17,11 @@ import (
 	"context"
 	"fmt"
 	"io"
+	"log/slog"
 	"net/http"
-
-	"github.com/go-kit/log"
-	"github.com/go-kit/log/level"
 )
 
-func getURL(ctx context.Context, hc *http.Client, log log.Logger, u string) ([]byte, error) {
+func getURL(ctx context.Context, hc *http.Client, log *slog.Logger, u string) ([]byte, error) {
 	req, err := http.NewRequestWithContext(ctx, http.MethodGet, u, nil)
 	if err != nil {
 		return nil, err
@@ -37,8 +35,8 @@ func getURL(ctx context.Context, hc *http.Client, log log.Logger, u string) ([]b
 	defer func() {
 		err = resp.Body.Close()
 		if err != nil {
-			level.Warn(log).Log(
-				"msg", "failed to close response body",
+			log.Warn(
+				"failed to close response body",
 				"err", err,
 			)
 		}
